@@ -5,14 +5,16 @@ from unity_build_pipeline.Modes.modes_base.command import InitedCommand, BaseCom
 from unity_build_pipeline.Modes.pipeline_modes.InitMode import InitMode
 from unity_build_pipeline.Modes.pipeline_modes.ExportMode import ExportMode
 from unity_build_pipeline.Modes.pipeline_modes.FastlaneMode import FastlaneMode
+from unity_build_pipeline.Services.Project import Project
 from unity_build_pipeline.Support.logger import color_print, WHITE
 
 class RapidCommand(BaseCommand):
     def run(self):
         kwargs = self.kwargs
         start_time = time.time()
-        
-        InitMode(kwargs).start()
+
+        if not Project.is_initialized(self.project_path) or kwargs.get('force', False):
+            InitMode(kwargs).start()
         ExportMode(kwargs).start()
         FastlaneMode(kwargs).start()
 
